// 英文报告模块
import { get,post } from "./index";

export default {
    /**
     * 获取报告列表
     * @param Frequency
     * @param ClassifyNameFirst
     * @param ClassifyNameSecond
     * @param KeyWord
     * @param EmailState
     * @param State
     * @param StartDate
     * @param EndDate
     */
    getList:params=>{
        return get('/english_report/list',params)
    },
    /**
     * 获取报告分类
     * @param CurrentIndex
     * @param PageSize
     * @param KeyWord
     */
    getClassifyList:params=>{
        return get('/english_report/classify/list',params)
    },
    /**
     * 删除报告
     * @param ReportIds
     */
    reportDel:params=>{
        return post('/english_report/delete',params)
    },
    /**
     * 发布报告
     * @param ReportIds 用,隔开
     */
    reportPublish:params=>{
        return post('/english_report/publish',params)
    },
    /**
     * 报告取消发布
     * @param ReportIds
     * @returns 
     */
    reportPublishCancle:params=>{
        return post('/english_report/publish/cancel',params)
    },
    /**
     * 报告详情
     * @param ReportId
     */
    getReportDetail:params=>{
        return get('/english_report/detail',params)
    },
    /**
     * 客户邮箱列表
     * @param CurrentIndex
     * @param PageSize
     * @param ListParam
     */
    getCustomEmailList:params=>{
        return get('/english_report/email/list',params)
    },
    /**
     * 批量群发邮件
     * @param ReportId
     * @param EmailIds
     * @param Theme
     * @param EnPermissions 选择的报告所关联的品种
     */
    sendEmail:params=>{
        return post('/english_report/email/send',params)
    },
    /**
     * 邮件群发日志
     * @param ReportId
     * @param SendStatus -1-已发送；0-发送失败；1-发送成功
     * @param CurrentIndex
     * @param PageSize
     */
    sendEmailLogList:params=>{
        return get('/english_report/email/log_list',params)
    },
    /**
     * 邮件重新推送
     * @param ReportId
     * @param SendId 0则重发所有失败的
     */
    emailResend:params=>{
        return post('/english_report/email/resend',params)
    },
    /**
     * 通过报告分类id获取报告内容（继承上一篇报告）
     * @param ClassifyIdFirst
     * @param ClassifyIdSecond
     */
    reportDetailByClassifyId(params){
        return get('/english_report/classifyIdDetail',params)
    },
    // 获取研报作者列表
    reportAuthorList(params){
        return get('/english_report/author',params)
    },
    /**
     * 新增英文报告
     */
    reportAdd(params){
        return post('/english_report/add',params)
    },
    /**
     * 编辑英文报告
     * @param ReportId
     */
    reportEdit(params){
        return post('/english_report/edit',params)
    },
    /**
     * 报告mark
     * @param ReportId
     * @param Status
     */
    reportMark(params){
        return post('/english_report/mark',params)
    },
    /**
     * 保存报告内容
     * @param ReportId
     * @param Content
     * @param NoChange 0内容没变 1内容变了
     */
    reportContentSave(params){
        return post('/english_report/saveReportContent',params)
    },
    /**
     * 策略同步过来的报告编辑
     */
    strategyReportEdit(params){
        return post('/english_report/edit_policy',params)
    },
    /**
     * 定时发布报告
     * @param ReportId
     * @param PrePublishTime
     */
    reportPublishTimeSet(params){
        return post('/english_report/pre_publish',params)
    },

    /**
     * 英文客户列表
     * @param {
     * PageSize - 每页数据量 - 必填
     * CurrentIndex - 当前页数 - 必填
     * Keywords - 客户名称
     * SortType - 点击量排序方式: 1-倒序;2-正序
     * } params 
     * @returns 
     */
    getCustomListEn: params => {
        return get('/english_report/company/list',params)
    },
    /**
     * 英文研报提交审批
     * @param {Object} params 
     * @param {Number} params.ReportId
     * @returns 
     */
    reportEnSubmit(params){
        return post("/english_report/approve/submit",params)
    },
    /**
     * 英文研报撤销审批
     * @param {Object} params 
     * @param {Number} params.ReportId
     * @returns 
     */
    reportEnCancel(params){
        return post("/english_report/approve/cancel",params)
    },
}